def cong(x,y):
    return x+y
    
def print_list(the_list,level):
    for item in the_list:
        if isinstance(item,list):
            print_list(item,level+1)
        else :
            for num in range(level):
                print("\t",end='')
            print(item)


from distutils.core import setup
setup( 
 name = 'tieu', 
 version = '1.0.1', 
 py_modules = ['tieu'],
 author = 'hfpython',
 author_email = 'hfpython@headfirstlabs.com',
 url = 'http://www.headfirstlabs.com',
 description = 'A simple printer of nested lists',
     )
